==> haskell-hspec-smallcheck-0.5.2-51-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-hspec-smallcheck.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: hspec-smallcheck
version: 0.5.2
id: hspec-smallcheck-0.5.2-8z2RjG8DVww7OUS9kTBK1
key: hspec-smallcheck-0.5.2-8z2RjG8DVww7OUS9kTBK1
license: MIT
copyright: (c) 2013-2018 Simon Hengel
maintainer: Simon Hengel <sol@typeful.net>
homepage: http://hspec.github.io/
synopsis: SmallCheck support for the Hspec testing framework
description:
    SmallCheck support for the Hspec testing framework
category: Testing
abi: 7e1481ffb5500078e405bf3726c030a7
exposed: True
exposed-modules:
    Test.Hspec.SmallCheck
hidden-modules: Test.Hspec.SmallCheck.Compat
                Test.Hspec.SmallCheck.Types Paths_hspec_smallcheck
import-dirs: /usr/lib/ghc-8.6.5/site-local/hspec-smallcheck-0.5.2
library-dirs: /usr/lib/ghc-8.6.5/site-local/hspec-smallcheck-0.5.2
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/hspec-smallcheck-0.5.2
hs-libraries: HShspec-smallcheck-0.5.2-8z2RjG8DVww7OUS9kTBK1
depends:
    HUnit-1.6.0.0-Kc3RXVOuMSQ9Y4PmNrdWEj base-4.12.0.0
    call-stack-0.1.0-J1eWgTNOnM4IGVyeW0v2YZ
    hspec-core-2.7.1-D3h8fPvFwWkAKgywE42l04
    smallcheck-1.1.5-IcJgcWLNXQN4xE4F00EnpE
haddock-interfaces: /usr/share/doc/haskell-hspec-smallcheck/html/hspec-smallcheck.haddock
haddock-html: /usr/share/doc/haskell-hspec-smallcheck/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-hspec-smallcheck-0.5.2-53-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-hspec-smallcheck.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: hspec-smallcheck
version: 0.5.2
id: hspec-smallcheck-0.5.2-FSbpa099Jy9HHKSVAS22jn
key: hspec-smallcheck-0.5.2-FSbpa099Jy9HHKSVAS22jn
license: MIT
copyright: (c) 2013-2018 Simon Hengel
maintainer: Simon Hengel <sol@typeful.net>
homepage: http://hspec.github.io/
synopsis: SmallCheck support for the Hspec testing framework
description:
    SmallCheck support for the Hspec testing framework
category: Testing
abi: 771e7abd39a157da640f054466b9feff
exposed: True
exposed-modules:
    Test.Hspec.SmallCheck
hidden-modules: Test.Hspec.SmallCheck.Compat
                Test.Hspec.SmallCheck.Types Paths_hspec_smallcheck
import-dirs: /usr/lib/ghc-8.6.5/site-local/hspec-smallcheck-0.5.2
library-dirs: /usr/lib/ghc-8.6.5/site-local/hspec-smallcheck-0.5.2
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/hspec-smallcheck-0.5.2
hs-libraries: HShspec-smallcheck-0.5.2-FSbpa099Jy9HHKSVAS22jn
depends:
    HUnit-1.6.0.0-Kc3RXVOuMSQ9Y4PmNrdWEj base-4.12.0.0
    call-stack-0.1.0-J1eWgTNOnM4IGVyeW0v2YZ
    hspec-core-2.7.1-GAgVZAe5BD33FzKgl8b1M
    smallcheck-1.1.5-IcJgcWLNXQN4xE4F00EnpE
haddock-interfaces: /usr/share/doc/haskell-hspec-smallcheck/html/hspec-smallcheck.haddock
haddock-html: /usr/share/doc/haskell-hspec-smallcheck/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
